/**
 * Introduction
 *
 * @title ROVLib - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file appquit.h
 *
 * @type subsystem
 *
 * @description
 *
 * The appquit subsystem is designed to handle applications exiting, either
 * through a menu, or reception of the WIMP task shutdown message.
 *
 * The subsystem maintains a number of 'edited files', which if zero allows an
 * application to terminate when requested, or if non-zero will call the unique
 * handler function, whose purpose is to report the number of opened files and
 * give the user to actually terminate the program, or to abort the termination.
 * 
 * The application does not have to have actual editied files; this is merely a
 * concept. For example, for a terminal emulator, you could have 'opened
 * windows' instead.
 */

#ifndef __rov_appquit
#define __rov_appquit


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Definition of an appquit handler function.
 * @see appquit_init()
 */
typedef void (*appquit_handler)(void);

/**
 * Initialise the appquit subsystem.
 * @param handler the appquit handler function.
 * @see appquit_handler()
 */
void appquit_init(appquit_handler handler);

/**
 * Set the number of edited files.
 * @param number the number of edited files.
 * @see appquit_quit()
 * @see appquit_addeditedfiles()
 */
void appquit_seteditedfiles(int number);

/**
 * Add to the number of edited files.
 * @param difference the difference in the number of edited files
 * @see appquit_quit()
 * @see appquit_seteditedfiles()
 */
void appquit_addeditedfiles(int difference);

/**
 * Called by the application when "Quit" is chosen from the application's menu.
 * @note This is not automatically called, and must be done by the application
 * code.
 * @see appquit_addeditedfiles()
 * @see appquit_seteditedfiles()
 */
void appquit_quit(void);


#ifdef __cplusplus
}
#endif

#endif
